#!/usr/bin/perl
#
# 	NAQuota v0.1, by Martin Knechtel (naquota@knechtel.it)
#	License: GPL (http://www.gnu.org/licenses/gpl.txt)
#	Description:
#	Requirements: Net-SNMP 5.0.9, PERL
#	
#	TODO:
############################################################################################################################
# 2006/05/11 mk,  Auslesen der quota Report Tabelle
###########################################################################################################################

$ARGS = @ARGV;
if($ARGS < 1){
	printf("Usaqe: $0 hostname communitystring warning critical\n");
	exit;
}

#### Configuration Variables.
my $BASE_DIR = "./";
my $SNMP_GET = "/usr/bin/snmpget";				# Location of snmpget command
my $SNMP_TABLE = "/usr/bin/snmptable";				# Location of snmptable command
my $MIB = "/usr/share/snmp/mibs/NETWORK-APPLIANCE-MIB.mib";			# Location of the NetApp MIB
my $HOST =	$ARGV[0];
my $COMMUNITY = $ARGV[1];						# Filer Community Name
my $WARNING =	$ARGV[2];						# factor of warning limit, e.g. 0.8 for 80% of the limit
my $CRITICAL =	$ARGV[3];						# factor of critical limit, e.g. 0.9 for 90% of the limit

my $MY_DOMAIN = "my.domain.tld";


## qr Output Key:
##	0 	qrV2Index (INT)
##	3 	qrV2HighKBytesUsed (INT)
##	4	qrV2LowKBytesUsed  (INT)
##	5	qrV2QuotaUnlimited  (INT), 0=true, 1=false
##	6 	qrV2HighKBytesLimit (INT)
##	7	qrV2LowKBytesLimit  (INT)
##	11	qrV2PathName (STR)
#####
# Addition to use the qrV264 counters
#####
##	24	qrV264KBytesUsed
##	25	qrV264KBytesLimit

@qr_output = `$SNMP_TABLE -v 2c -c $COMMUNITY -C Hf \: -m $MIB $ARGV[0] NETWORK-APPLIANCE-MIB::qrV2Table | grep vol`;
#@qr_output = `$SNMP_TABLE -v 2c -c $COMMUNITY -C Hf \: -m $MIB $ARGV[0] NETWORK-APPLIANCE-MIB::qrV2Table`;

$warn_counter=0;
$crit_counter=0;
$criticalQuota="";
$warningQuota="";

foreach(@qr_output){
	chomp($_);
	my @qr_line = split(/:/);
	$qr_line[11] =~ s/\"//g;		# Prune off the qotes on the quota name.
						
#	$used		= $qr_line[3]*4294967296+$qr_line[4];
	$used		= $qr_line[3]*4294967296+$qr_line[24];
#	$threshold	= $qr_line[6]*4294967296+$qr_line[7];
	$threshold	= $qr_line[6]*4294967296+$qr_line[25];
#	print "used: ".$used." threshold: ".$threshold."\n";

	if($qr_line[5] =~ m/false/ && $used > $WARNING*$threshold) {
		$warn_counter++;
		$warningQuota .= $qr_line[11]." (".sprintf("%0.1f", ($used*100/$threshold))."%), ";
	}

	if($qr_line[5] =~ m/false/ && $used > $CRITICAL*$threshold) {
		$crit_counter++;
		$criticalQuota .= $qr_line[11]." (".sprintf("%0.1f", ($used*100/$threshold))."%), ";
	}
}

if ($crit_counter > 0) {
	print "CRITICAL - ".$crit_counter." exceeded quota: ".$criticalQuota;
	exit(2);
}elsif ($warn_counter > 0) {
	print "WARNING - ".$warn_counter." exceeded quota: ".$warningQuota;
	exit(1);
}else {
	print "OK - no volumes exceed thresholds";
	exit(0);
}

#################################################################################
#    This program is free software; you can redistribute it and/or modify	#
#    it under the terms of the GNU General Public License as published by	#
#    the Free Software Foundation; either version 2 of the License, or		#
#    (at your option) any later version.					#
#										#
#    This program is distributed in the hope that it will be useful,		#
#    but WITHOUT ANY WARRANTY; without even the implied warranty of		#
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the		#
#    GNU General Public License for more details.				#
#										#
#    You should have received a copy of the GNU General Public License		#
#    along with this program; if not, write to the Free Software		#
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA	#
#################################################################################
